# #####################################
# ### best scenario, parameters estimate
# ####################################

### Adapt the working directory
exportFile <- "C:/Users/Admin/Desktop/"
setwd(exportFile)
###Load libraries
library("abc") # version 2.1 
library("ggplot2") # 3.3.3
library("HDInterval") # version 0.2.2
# abc.data 1.0, locfit 1.5-9.4, quantreg 5.85, SparseM 1.81, base 4.0.5, datasets 4.0.5, graphics 4.0.5, grDevices 4.0.5, MASS 7.3-53.1, methods 4.0.5, nnet 7.3-15, stats 4.0.5, utils 4.0.5, 

################
### IMPORT DATA
################
simData <- read.table("paramList.sampled.neural.4.estParam.fix.csv", header=TRUE)
neuralnetAdjValues <- read.table("neuralnet.sampled.neural.4.estParam.fix_adj.values.csv", header=TRUE)
cvTrue <- read.table("cv.neural.sampled.4_true.csv", header=TRUE)
cvEstim <- read.table("cv.neural.sampled.4_estim_tol0.01.csv", header=TRUE)


################
### DO THE PLOT
################

###Plot properties
data.colpost <- "black" ; data.coldemogpost <- "black"
data.adjust <- 1.0
data.main <- c(
  expression(paste("Admixture rate ", (italic(gamma)))),
  expression(paste("Long distance dispersal rate ", (italic("LDD")))),
  expression(paste("Population drop strength ", (italic(""[S]*"DD")))))
data.minPrior <- c(0, 0, 0.5)
data.maxPrior <- c(0.03, 0.05, 0.8)

###Make Figure 2
data.width <- 1000 ; data.height <- 1000
  tiff(paste(exportFile,"Figure2.tiff",sep=""), units="in", width=10, height=10, res=300)
  par(mfrow=c(3,2), 
      mai = c(1, 1, 0.3, 0.5),
      cex=1.2)
  ######Gamma
  data.value <- 1
  data.title <- data.main[data.value]
  data.demogPost <- simData[,data.value] ; data.post <- neuralnetAdjValues[,data.value]
  dens <- density(data.post, adjust = data.adjust)
  plot(dens,
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(0,max(dens$y)*1.1),
       main="", #data.title, 
       col=data.colpost, 
       xaxs="i", yaxs="i", 
       xlab=data.title, 
       ylab="Density")
  xx <- cbind(dens$x,dens$x) ; yy <- cbind(dens$y,dens$y)
  polygon(xx,yy, col=grey(0.5),border = "black", lty= 1, lwd=1)
  dens2<-cbind(x=dens$x, y=dens$y)
  dens2<-subset(dens2, dens2[,"x"]>=data.minPrior[data.value])
  dens2<-subset(dens2, dens2[,"x"]<=data.maxPrior[data.value])
  xx2 <- cbind(dens2[,"x"],rev(dens2[,"x"])) ; yy2 <- cbind(dens2[,"y"],0)
  polygon(xx2,yy2, col=grey(0.8),border = NA, lty= 1, lwd=1)
  ##Do prior
  abline(v=data.minPrior[data.value], lty=3)
  abline(v=data.maxPrior[data.value], lty=3)
  abline(h=1/(data.maxPrior[data.value]-data.minPrior[data.value]), lty=3)
  ##Do demog posterior
  lines(density(data.demogPost, adjust = data.adjust), col=data.coldemogpost, lty=2)
  plot(cvTrue[,data.value],cvEstim[,data.value],xlab="True",
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       xaxs="i", yaxs="i", 
       ylab="Estimate")
  abline(coef = c(0,1))
  abline(lm(cvEstim[,data.value] ~ cvTrue[,data.value]), col="red")
  ######LDD
  data.value <- 2
  data.title <- data.main[data.value]
  data.demogPost <- simData[,data.value] ; data.post <- neuralnetAdjValues[,data.value]
  dens <- density(data.post, adjust = data.adjust)
  plot(dens,
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(0,max(dens$y)*1.1),
       main="", #data.title, 
       col=data.colpost, 
       xaxs="i", yaxs="i",  
       xlab=data.title, 
       ylab="Density")
  xx <- cbind(dens$x,dens$x) ; yy <- cbind(dens$y,dens$y)
  polygon(xx,yy, col=grey(0.5),border = "black", lty= 1, lwd=1)
  dens2<-cbind(x=dens$x, y=dens$y)
  dens2<-subset(dens2, dens2[,"x"]>=data.minPrior[data.value])
  dens2<-subset(dens2, dens2[,"x"]<=data.maxPrior[data.value])
  xx2 <- cbind(dens2[,"x"],rev(dens2[,"x"])) ; yy2 <- cbind(dens2[,"y"],0)
  polygon(xx2,yy2, col=grey(0.8),border = NA, lty= 1, lwd=1)
  ##Do prior
  abline(v=data.minPrior[data.value], lty=3)
  abline(v=data.maxPrior[data.value], lty=3)
  abline(h=1/(data.maxPrior[data.value]-data.minPrior[data.value]), lty=3)
  ##Do demog posterior
  lines(density(data.demogPost, adjust = data.adjust), col=data.coldemogpost, lty=2)
  plot(cvTrue[,data.value],cvEstim[,data.value],xlab="True",
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       xaxs="i", yaxs="i", 
       ylab="Estimate")
  abline(coef = c(0,1))
  abline(lm(cvEstim[,data.value] ~ cvTrue[,data.value]), col="red")
  ######Drop strength
  data.value <- 3
  data.title <- data.main[data.value]
  data.demogPost <- simData[,data.value] ; data.post <- neuralnetAdjValues[,data.value]
  dens <- density(data.post, adjust = data.adjust)
  plot(dens,
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(0,max(dens$y)*1.1),
       main="", #data.title, 
       col=data.colpost, 
       xaxs="i", yaxs="i",  
       xlab=data.title, 
       ylab="Density")
  xx <- cbind(dens$x,dens$x) ; yy <- cbind(dens$y,dens$y)
  polygon(xx,yy, col=grey(0.5),border = "black", lty= 1, lwd=1)
  dens2<-cbind(x=dens$x, y=dens$y)
  dens2<-subset(dens2, dens2[,"x"]>=data.minPrior[data.value])
  dens2<-subset(dens2, dens2[,"x"]<=data.maxPrior[data.value])
  xx2 <- cbind(dens2[,"x"],rev(dens2[,"x"])) ; yy2 <- cbind(dens2[,"y"],0)
  polygon(xx2,yy2, col=grey(0.8),border = NA, lty= 1, lwd=1)
  ##Do prior
  abline(v=data.minPrior[data.value], lty=3)
  abline(v=data.maxPrior[data.value], lty=3)
  abline(h=1/(data.maxPrior[data.value]-data.minPrior[data.value]), lty=3)
  ##Do demog posterior
  lines(density(data.demogPost, adjust = data.adjust), col=data.coldemogpost, lty=2)
  plot(cvTrue[,data.value],cvEstim[,data.value],xlab="True",
       xlim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       ylim=c(data.minPrior[data.value],data.maxPrior[data.value]),
       xaxs="i", yaxs="i", 
       ylab="Estimate")
  abline(coef = c(0,1))
  abline(lm(cvEstim[,data.value] ~ cvTrue[,data.value]), col="red")
  dev.off() 

